/***************************************************************************//**
* \file CSD_Comp_1.h
* \version 1.0
*
* \brief
*  This file provides constants and parameter values for the Comparator
*  component.
*
********************************************************************************
* \copyright
* Copyright 2016, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CSD_Comp_P4_CSD_Comp_1_H)
#define CY_CSD_Comp_P4_CSD_Comp_1_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h"

#include "CSD_Comp_1_SampleClk.h"


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define CSD_Comp_1_VOLTAGE_REF_SOURCE         (1u)
#define CSD_Comp_1_VOLTAGE_REF_TYPE           (0u)
#define CSD_Comp_1_TAP                        (32UL)


/***************************************
*       Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
} CSD_Comp_1_backup_struct;


/***************************************
*        Function Prototypes
***************************************/
/**
* \addtogroup group_general
* @{
*/
void CSD_Comp_1_Init(void);
void CSD_Comp_1_Enable(void);
void CSD_Comp_1_Start(void);
void CSD_Comp_1_Stop(void);
void CSD_Comp_1_SetReferenceVoltageType(uint32 refVoltageType);
void CSD_Comp_1_SetVoltageTap(uint32 voltageTap);
uint32 CSD_Comp_1_GetCompare(void);
/** @} group_general */
/**
* \addtogroup group_power
* @{
*/
void CSD_Comp_1_Sleep(void);
void CSD_Comp_1_Wakeup(void);
/** @} power */


/***************************************
*           Global Variables
***************************************/
/**
* \addtogroup group_globals
* @{
*/
extern uint8 CSD_Comp_1_initVar;
/** @} globals */


/***************************************
*           API Constants
***************************************/

/* Calculating divider for SampleClock to have its frequency equal to SYSCLK  */
#define CSD_Comp_1_SAMPLECLK_DIVIDER          (CYDEV_BCLK__HFCLK__MHZ/CYDEV_BCLK__SYSCLK__MHZ)

#define CSD_Comp_1_VREF_STEP_MVOLTS           (38u)
#define CSD_Comp_1_REFGEN_GAIN                (31UL)

#define CSD_Comp_1_FIXED_REF_VOLTAGE          (0u)
#define CSD_Comp_1_ADJUSTABLE_REF_VOLTAGE     (1u)

#define CSD_Comp_1_INTERNAL_BANDGAP_REFERENCE (0u)
#define CSD_Comp_1_EXTERNAL_REFERENCE         (1u)

/* Startup timeouts for different parts of CSD IP in micro seconds */
#define CSD_Comp_1_CSD_IP_STARTUP_TIMEOUT     (5u)
#define CSD_Comp_1_REFGEN_STARTUP_TIMEOUT     (10u)
#define CSD_Comp_1_CSDCMP_STARTUP_TIMEOUT     (1u)

#define CSD_Comp_1_2000_MV                    (2000u)
#ifdef CYDEV_VDDA_MV
    #define CSD_Comp_1_CYDEV_VDDA_MV          (CYDEV_VDDA_MV)
#else
    #define CSD_Comp_1_CYDEV_VDDA_MV          (CYDEV_VDD_MV)
#endif  /* CYDEV_VDDA_MV */

#if (CSD_Comp_1_FIXED_REF_VOLTAGE == CSD_Comp_1_VOLTAGE_REF_TYPE)
    #define CSD_Comp_1_CSD_SW_CMP_N_SEL_REG_INIT (CSD_Comp_1_SW_SCRH_CLOSED)
    #define CSD_Comp_1_CSD_REFGEN_SW_CFG         (CSD_Comp_1_BYPASS)
#else /* CSD_Comp_1_ADJUSTABLE_REF_VOLTAGE */
    #define CSD_Comp_1_CSD_SW_CMP_N_SEL_REG_INIT (CSD_Comp_1_SW_SCRL_CLOSED)
    #define CSD_Comp_1_CSD_REFGEN_SW_CFG         (CSD_Comp_1_RES_EN)
#endif /* (CSD_Comp_1_FIXED_REF_VOLTAGE == CSD_Comp_1_VOLTAGE_REF_TYPE) */

#define CSD_Comp_1_CSD_CONFIG_REG_INIT        (CSD_Comp_1_CSD_ENABLE | CSD_Comp_1_CSD_SENSE_EN)
#define CSD_Comp_1_CSD_REFGEN_REG_INIT        (CSD_Comp_1_CSD_REFGEN_SW_CFG | \
            (uint32) (CSD_Comp_1_REFGEN_GAIN << CYFLD_CSD_GAIN__OFFSET) | \
            (uint32) ((CSD_Comp_1_TAP - 1u) << CYFLD_CSD_VREFLO_SEL__OFFSET))
#define CSD_Comp_1_CSD_CSDCMP_REG_INIT        (CSD_Comp_1_CMP_MODE | CSD_Comp_1_FEEDBACK_MODE)


/***************************************
*             Registers
***************************************/

/* CSD IP block registers */
#define CSD_Comp_1_CSD_CONFIG_REG             (*(reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__CSD_CONFIG)
#define CSD_Comp_1_CSD_CONFIG_PTR             ( (reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__CSD_CONFIG)
#define CSD_Comp_1_CSD_STATUS_REG             (*(reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__CSD_STATUS)
#define CSD_Comp_1_CSD_STATUS_PTR             ( (reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__CSD_STATUS)
#define CSD_Comp_1_CSD_CSDCMP_REG             (*(reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__CSDCMP)
#define CSD_Comp_1_CSD_CSDCMP_PTR             ( (reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__CSDCMP)
#define CSD_Comp_1_CSD_REFGEN_REG             (*(reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__REFGEN)
#define CSD_Comp_1_CSD_REFGEN_PTR             ( (reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__REFGEN)
#define CSD_Comp_1_CSD_SW_CMP_N_SEL_REG       (*(reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__SW_CMP_N_SEL)
#define CSD_Comp_1_CSD_SW_CMP_N_SEL_PTR       ( (reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__SW_CMP_N_SEL)
#define CSD_Comp_1_CSD_SW_AMUXBUF_SEL_REG     (*(reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__SW_AMUXBUF_SEL)
#define CSD_Comp_1_CSD_SW_AMUXBUF_SEL_PTR     ( (reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__SW_AMUXBUF_SEL)
#define CSD_Comp_1_CSD_SW_REFGEN_SEL_REG      (*(reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__SW_REFGEN_SEL)
#define CSD_Comp_1_CSD_SW_REFGEN_SEL_PTR      ( (reg32*) CSD_Comp_1_cy_psoc4_csd_v2_comp__SW_REFGEN_SEL)


/***************************************
*       Register Constants
***************************************/

/* CSD IP block Configuration and control register bits */
#define CSD_Comp_1_CSD_ENABLE                 ((uint32) (0x01UL << CYFLD_CSD_ENABLE__OFFSET))
#define CSD_Comp_1_CSD_SENSE_EN               ((uint32) (0x01UL << CYFLD_CSD_SENSE_EN__OFFSET))

/* CSD IP block Status register bits */
#define CSD_Comp_1_CSDCMP_OUT                 ((uint32) (0x01UL << CYFLD_CSD_CSDCMP_OUT__OFFSET))

/* CSD IP block Reference Generator configration register bits */
#define CSD_Comp_1_REFGEN_EN                  ((uint32) (0x01UL << CYFLD_CSD_REFGEN_EN__OFFSET))
#define CSD_Comp_1_BYPASS                     ((uint32) (0x01UL << CYFLD_CSD_BYPASS__OFFSET))
#define CSD_Comp_1_RES_EN                     ((uint32) (0x01UL << CYFLD_CSD_RES_EN__OFFSET))
#define CSD_Comp_1_GAIN_MASK                  ((uint32) (0x1FUL << CYFLD_CSD_GAIN__OFFSET))
#define CSD_Comp_1_VREFLO_SEL_MASK            ((uint32) (0x1FUL << CYFLD_CSD_VREFLO_SEL__OFFSET))

/* CSD IP block Comparator configuration register bits */
#define CSD_Comp_1_CSDCMP_EN                  ((uint32) (0x01UL << CYFLD_CSD_CSDCMP_EN__OFFSET))
#define CSD_Comp_1_CMP_MODE                   ((uint32) (0x01UL << CYFLD_CSD_CMP_MODE__OFFSET))
#define CSD_Comp_1_FEEDBACK_MODE              ((uint32) (0x01UL << CYFLD_CSD_FEEDBACK_MODE__OFFSET))

/* CSD IP block Negative comparator input switch configuration register bits */
#define CSD_Comp_1_SW_SCRH_CLOSED             ((uint32) (0x01UL << CYFLD_CSD_SW_SCRH__OFFSET))
#define CSD_Comp_1_SW_SCRL_CLOSED             ((uint32) (0x01UL << CYFLD_CSD_SW_SCRL__OFFSET))

/* CSD IP block Amux buffer switch configuration register bits */
#define CSD_Comp_1_SW_IRLB_CLOSED             ((uint32) (0x01UL << CYFLD_CSD_SW_IRLB__OFFSET))
#define CSD_Comp_1_SW_IRH_CLOSED              ((uint32) (0x01UL << CYFLD_CSD_SW_IRH__OFFSET))

/* CSD IP block Reference Generator switch configuration register bits */
#define CSD_Comp_1_SW_SGMB_CLOSED             ((uint32) (0x01UL << CYFLD_CSD_SW_SGMB__OFFSET))
#define CSD_Comp_1_SW_SGRE_CLOSED             ((uint32) (0x01UL << CYFLD_CSD_SW_SGRE__OFFSET))
#define CSD_Comp_1_SW_SGR_CLOSED              ((uint32) (0x01UL << CYFLD_CSD_SW_SGR__OFFSET))

#endif /* End CY_CSD_Comp_P4_CSD_Comp_1_H */


/* [] END OF FILE */
